===================================================
sphinx-intl: translation support utility for Sphinx
===================================================

``sphinx-intl`` is a utility tool that provides several features that make it
easy to translate and to apply translation to Sphinx_ generated document.
Optional: support the Transifex service for translation with Sphinx_ .

.. _Sphinx: http://sphinx-doc.org

.. image:: https://img.shields.io/readthedocs/sphinx-intl/master.svg
   :alt: Read the Docs (master)
   :target: http://sphinx-intl.rtfd.io/

.. image:: https://img.shields.io/pypi/v/sphinx-intl.svg
   :alt: PyPI
   :target: http://pypi.org/p/sphinx-intl

.. image:: https://img.shields.io/pypi/pyversions/sphinx-intl.svg
   :alt: PyPI - Python Version

.. image:: https://img.shields.io/github/license/sphinx-doc/sphinx-intl.svg
   :alt: License
   :target: https://github.com/sphinx-doc/sphinx-intl/blob/master/LICENSE

.. image:: https://img.shields.io/travis/sphinx-doc/sphinx-intl/master.svg
   :alt: Travis (.org) branch
   :target: https://travis-ci.org/sphinx-doc/sphinx-intl

.. image:: https://img.shields.io/github/stars/sphinx-doc/sphinx-intl.svg?style=social&label=Stars
   :alt: GitHub stars
   :target: https://github.com/sphinx-doc/sphinx-intl

Documentation
=============

- http://sphinx-intl.rtfd.io/


License
=======
Licensed under the BSD license.


CHANGES
=======

See: https://sphinx-intl.readthedocs.io/en/master/changes.html